"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

require("./modal.css");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Modal = function Modal(_ref) {
  var isActive = _ref.isActive,
      children = _ref.children,
      containerClassName = _ref.containerClassName,
      bodyClassName = _ref.bodyClassName,
      onClose = _ref.onClose;
  var containerRef;

  var setWrapperRef = function setWrapperRef(node) {
    containerRef = node;
  };

  var handleClose = function handleClose(event) {
    if (event.type === 'mousedown') {
      if (containerRef && !containerRef.contains(event.target)) {
        onClose();
      }
    }

    if (event.type === 'keydown' && event.keyCode === 27) {
      onClose();
    }
  };

  if (onClose) {
    _react.default.useEffect(function () {
      document.addEventListener('mousedown', function (event) {
        return handleClose(event);
      });
      document.addEventListener('keydown', function (event) {
        return handleClose(event);
      });
      return function () {
        document.removeEventListener('mousedown', function (event) {
          return handleClose(event);
        });
        document.removeEventListener('keydown', function (event) {
          return handleClose(event);
        });
      };
    });
  }

  var finalContainerClassNames = "react-modable-modal-container".concat(containerClassName ? " ".concat(containerClassName) : '');
  var finalBodyClassNames = "react-modable-modal-body".concat(bodyClassName ? " ".concat(bodyClassName) : '');

  if (isActive) {
    return _react.default.createElement("section", {
      className: finalContainerClassNames
    }, _react.default.createElement("div", {
      className: finalBodyClassNames,
      ref: setWrapperRef
    }, children));
  }

  return null;
};

Modal.defaultProps = {
  isActive: false,
  containerClassName: undefined,
  bodyClassName: undefined,
  onClose: undefined
};
Modal.propTypes = {
  isActive: _propTypes.default.bool,
  children: _propTypes.default.oneOfType([_propTypes.default.arrayOf(_propTypes.default.node), _propTypes.default.node]).isRequired,
  containerClassName: _propTypes.default.string,
  bodyClassName: _propTypes.default.string,
  onClose: _propTypes.default.func
};
var _default = Modal;
exports.default = _default;